import os

from setuptools import setup, find_packages


def read(f_name):
    return open(os.path.join(os.path.dirname(__file__), f_name)).read()


setup(
    name='nwg-shell-config',
    version='0.5.65',
    description='nwg-shell configuration utility',
    packages=find_packages(),
    include_package_data=True,
    package_data={
        "": ["glade/*", "autotranslate/*", "langs/*", "dialog/*", "hud/*", "shell/*", "updates/*"]
    },
    url='https://github.com/nwg-piotr/nwg-shell-config',
    license='MIT',
    author='Piotr Miller',
    author_email='nwg.piotr@gmail.com',
    python_requires='>=3.5.0',
    install_requires=[],
    entry_points={
        'gui_scripts': [
            'nwg-autotranslate = nwg_shell_config.autotranslate:main',
            'nwg-shell-config = nwg_shell_config.main:main',
            'nwg-shell-config-sway = nwg_shell_config.main_sway:main',
            'nwg-shell-config-hyprland = nwg_shell_config.main_hyprland:main',
            'nwg-lock = nwg_shell_config.locker:main',
            'nwg-shell-help = nwg_shell_config.help:main',
            'nwg-autotiling = nwg_shell_config.autotiling:main',
            'nwg-shell-translate = nwg_shell_config.translate:main',
            'nwg-update-indicator = nwg_shell_config.update_indicator:main',
            'nwg-screenshot-applet = nwg_shell_config.screenshot_applet:main',
            'nwg-dialog = nwg_shell_config.dialog:main',
            'nwg-hud = nwg_shell_config.hud:main'
        ]
    }
)



#!/usr/bin/env python3

"""
nwg-shell config utility
Repository: https://github.com/nwg-piotr/nwg-shell-config
Project site: https://nwg-piotr.github.io/nwg-shell
Author's email: nwg.piotr@gmail.com
Copyright (c) 2021-2025 Piotr Miller & Contributors
License: MIT
"""

import argparse
import os
import sys
import subprocess

from nwg_shell_config.tools import eprint, load_shell_data
from nwg_shell_config.__about__ import __version__

arguments = " ".join(sys.argv[1:])


def main():
    # We actually support just -v and -h her. The rest is to display proper help content, as they're being passed farther anyway.
    parser = argparse.ArgumentParser()
    parser.add_argument("-v",
                        "--version",
                        action="version",
                        version="%(prog)s version {}".format(__version__),
                        help="display version information")
    parser.add_argument("-r",
                        "--restore",
                        action="store_true",
                        help="restore default presets")

    parser.add_argument("-b",
                        "--restore_backup",
                        type=str,
                        default="",
                        help="restore all configs from a backup file (given path)")

    parser.add_argument("-s",
                        "--save",
                        action="store_true",
                        help="load settings & Save includes (for use w/ external scripts)")

    parser.parse_args()

    shell_data = load_shell_data()
    if not shell_data["autotranslated"]:
        subprocess.Popen("nwg-autotranslate")

        if os.getenv("HYPRLAND_INSTANCE_SIGNATURE"):
            eprint("Labels translated, reloading Hyprland.")
            subprocess.Popen("hyprctl reload".split())
        else:
            eprint("Labels translated, reloading sway.")
            subprocess.Popen("swaymsg reload".split())

    if os.getenv("SWAYSOCK"):
        cmd = "nwg-shell-config-sway {}".format(arguments)
        eprint("Starting sway version")
    elif os.getenv("HYPRLAND_INSTANCE_SIGNATURE"):
        cmd = "nwg-shell-config-hyprland {}".format(arguments)
        eprint("Starting Hyprland version")
    else:
        eprint("This program needs either sway or Hyprland environment")
        sys.exit(1)
    try:
        subprocess.Popen(cmd.split())
        sys.exit(0)
    except Exception as e:
        eprint(e)
        sys.exit(1)


if __name__ == "__main__":
    main()
